@@ -21,30 +21,43 @@ babyphone - A baby monitor application on the Nokia N900.
 #include <QDialog>
 
 
-// settings
+// settings keys and default values
 #define COMPANY                         "morawek.at"
 #define PRODUCT                         "babyphone"
 #define PHONE_NUMBER_KEY                "phoneNumber"
 #define PHONE_NUMBER_DEFAULT            ""
 #define AUDIO_AMPLIFY_KEY               "audio/volume"
-#define AUDIO_AMPLIFY_DEFAULT           27
+#define AUDIO_AMPLIFY_DEFAULT           16
 #define AUDIO_TIMER_KEY                 "audio/timer"
 #define AUDIO_TIMER_DEFAULT             4
+#define CALL_SETUP_TIMER_KEY            "call/setupTimer"
+#define CALL_SETUP_TIMER_DEFAULT        30
+#define ACTIVATION_DELAY_KEY            "application/activationDelay"
+#define ACTIVATION_DELAY_DEFAULT        0
 #define RECALL_TIMER_KEY                "call/recallTimer"
-#define RECALL_TIMER_DEFAULT            30
+#define RECALL_TIMER_DEFAULT            180
+#define SWITCH_PROFILE_KEY              "application/switchProfile"
+#define SWITCH_PROFILE_DEFAULT          true
+#define SEND_SMS_KEY                    "application/sendSMS"
+#define SEND_SMS_DEFAULT                false
 #define REJECT_INCOMING_CALLS_KEY       "call/rejectIncoming"
 #define REJECT_INCOMING_CALLS_DEFAULT   true
+#define DISABLE_GRAPHS_KEY              "view/disableGraphsWhileMonitoring"
+#define DISABLE_GRAPHS_DEFAULT          false
 
 
-
+/*!
+  The constructor initializes the constant settings and loads the saved values
+  from the persistant storage.
+*/
 Settings::Settings(QObject *parent) :
     QSettings(COMPANY, PRODUCT, parent),
-    CALL_SETUP_TIMER(30000),    // 30s maximum call setup time
     CALL_HOLD_TIMER(300000),    // 300s maximum call time
-    MSG_BOX_TIMEOUT(10000),     // 10s until auto-close of message boxes
     THRESHOLD_VALUE(100),
     VOLUME_COUNTER_MAX(120),    // clipping occurs at this value
     VOLUME_COUNTER_DEC(1),
+    MSG_BOX_TIMEOUT(10000),     // 10s until auto-close of message boxes
+    REFOCUS_TIMER(2000),        // 2s after the call is finished
     GRAPH_MIN_VALUE(0),         // minimum value that is shown
     GRAPH_MAX_VALUE(130),       // maximum value that is shown
     GRAPH_WIDTH(579),           // static value determined by UI design
@@ -52,26 +65,43 @@ Settings::Settings(QObject *parent) :
     AUDIO_SAMPLE_INTERVAL(800),
     AUDIO_SAMPLE_SUBINTERVAL(16),
     AUDIO_ON_TIMER(5000),
-    AUDIO_OFF_TIMER(300)
+    AUDIO_OFF_TIMER(100)
 {
     itsAudioAmplify = value(AUDIO_AMPLIFY_KEY, AUDIO_AMPLIFY_DEFAULT).toInt();
     itsAudioTimer = value(AUDIO_TIMER_KEY, AUDIO_TIMER_DEFAULT).toInt();
     itsPhonenumber = value(PHONE_NUMBER_KEY, PHONE_NUMBER_DEFAULT).toString();
+    itsCallSetupTimer = value(CALL_SETUP_TIMER_KEY, CALL_SETUP_TIMER_DEFAULT).toInt();
+    itsActivationDelay = value(ACTIVATION_DELAY_KEY, ACTIVATION_DELAY_DEFAULT).toInt();
     itsRecallTimer = value(RECALL_TIMER_KEY, RECALL_TIMER_DEFAULT).toInt();
-    itsRejectIncomingCalls = value(REJECT_INCOMING_CALLS_KEY, REJECT_INCOMING_CALLS_DEFAULT).toBool();
+    itsSwitchProfile = value(SWITCH_PROFILE_KEY, SWITCH_PROFILE_DEFAULT).toBool();
+    itsSendSMS = value(SEND_SMS_KEY, SEND_SMS_DEFAULT).toBool();
+    itsHandleIncomingCalls = value(REJECT_INCOMING_CALLS_KEY, REJECT_INCOMING_CALLS_DEFAULT).toBool();
+    itsDisableGraphs = value(DISABLE_GRAPHS_KEY, DISABLE_GRAPHS_DEFAULT).toBool();
 }
 
 
+/*!
+  Save saves all current setting values to the persistant storage.
+*/
 void Settings::Save()
 {
     setValue(AUDIO_AMPLIFY_KEY, itsAudioAmplify);
     setValue(AUDIO_TIMER_KEY, itsAudioTimer);
     setValue(PHONE_NUMBER_KEY, itsPhonenumber);
+    setValue(CALL_SETUP_TIMER_KEY, itsCallSetupTimer);
+    setValue(ACTIVATION_DELAY_KEY, itsActivationDelay);
     setValue(RECALL_TIMER_KEY, itsRecallTimer);
-    setValue(REJECT_INCOMING_CALLS_KEY, itsRejectIncomingCalls);
+    setValue(SWITCH_PROFILE_KEY, itsSwitchProfile);
+    setValue(SEND_SMS_KEY, itsSendSMS);
+    setValue(REJECT_INCOMING_CALLS_KEY, itsHandleIncomingCalls);
+    setValue(DISABLE_GRAPHS_KEY, itsDisableGraphs);
 }
 
 
+/*!
+  ShowDialog opens the settings user interface dialog and stores its values if
+  demanded.
+*/
 void Settings::ShowDialog()
 {
     // setup settings dialog
@@ -80,8 +110,13 @@ void Settings::ShowDialog()
     ui->setupUi(dialog);
     ui->spinBox_volume->setValue(itsAudioAmplify);
     ui->spinBox_timeWeight->setValue(itsAudioTimer);
+    ui->spinBox_callSetupTimer->setValue(itsCallSetupTimer);
+    ui->spinBox_activationDelay->setValue(itsActivationDelay);
     ui->spinBox_recallTimer->setValue(itsRecallTimer);
-    ui->checkBox_rejectIncomingCalls->setChecked(itsRejectIncomingCalls);
+    ui->checkBox_switchProfile->setChecked(itsSwitchProfile);
+    ui->checkBox_sendSMS->setChecked(itsSendSMS);
+    ui->checkBox_rejectIncomingCalls->setChecked(itsHandleIncomingCalls);
+    ui->checkBox_disableGraphs->setChecked(itsDisableGraphs);
 
     // show dialog
     if (dialog->exec() == QDialog::Accepted)
@@ -89,8 +124,13 @@ void Settings::ShowDialog()
         // store new settings
         itsAudioAmplify = ui->spinBox_volume->value();
         itsAudioTimer = ui->spinBox_timeWeight->value();
+        itsCallSetupTimer = ui->spinBox_callSetupTimer->value();
+        itsActivationDelay = ui->spinBox_activationDelay->value();
         itsRecallTimer = ui->spinBox_recallTimer->value();
-        itsRejectIncomingCalls = ui->checkBox_rejectIncomingCalls->checkState();
+        itsSwitchProfile = ui->checkBox_switchProfile->checkState();
+        itsSendSMS = ui->checkBox_sendSMS->checkState();
+        itsHandleIncomingCalls = ui->checkBox_rejectIncomingCalls->checkState();
+        itsDisableGraphs = ui->checkBox_disableGraphs->checkState();
     }
 
     // clean up
